==> wikindx3_2_2.tar.gz: wikindx3/core/browse/BROWSEKEYWORD.php <==
<?php
/**********************************************************************************
WIKINDX: Bibliographic Management system.
Copyright (C)

This program is free software; you can redistribute it and/or modify it under the terms
of the GNU General Public License as published by the Free Software Foundation; either
version 2 of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License along with this program;
if not, write to the
Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA

The WIKINDX Team 2005
sirfragalot@users.sourceforge.net

**********************************************************************************/
/*****
* BROWSEKEYWORD class
*
* Browse keywords as a 'tag cloud'
*
* 
$Header: /cvsroot/wikindx/wikindx3/core/browse/BROWSEKEYWORD.php,v 1.4 2005/12/20 07:36:22 sirfragalot Exp $
*****/
class BROWSEKEYWORD
{
// Constructor
	function BROWSEKEYWORD($db)
	{
		$this->db = $db;
		include_once("core/html/MISC.php");
		include_once("core/html/HTML.php");
		$this->html = new HTML();
		include_once("core/messages/MESSAGES.php");
		$this->messages = new MESSAGES();
		include_once("core/template/TEMPLATE.php");
		$this->template = new TEMPLATE('content');
		include_once("core/browse/BROWSECOMMON.php");
		$this->common = new BROWSECOMMON($this->db);
		include_once("core/session/SESSION.php");
		$this->session = new SESSION();
	}
// display keywords
	function display()
	{
		$this->template->setVar('heading', $this->messages->text("heading", "browseKeyword"));
		$this->sum = $this->keyword = array();
		$this->getKeywords();
		if(empty($this->keyword))
		{
			$pString = MISC::p("&nbsp;") . $this->messages->text("misc", "noKeywords");
			$this->template->setVar('body', $pString);
			return $this->template->process();
		}
		asort($this->sum);
		asort($this->keyword);
		$pString = MISC::p($this->bib, "hint") . 
			MISC::pBrowse($this->process(), "center");
		$this->template->setVar('body', $pString);
		return $this->template->process();
	}
// Process and display results
	function process()
	{
		$lowestSum = current($this->sum);
		$highestSum = end($this->sum);
		foreach($this->keyword as $id => $name)
		{
//			$name = str_replace(' ', "&nbsp;", $name);
			$name = $this->html->codeToHtml($name);
			list($red, $colour) = $this->common->colourText($lowestSum, $highestSum, $this->sum[$id]);
			$size = $this->common->sizeText($lowestSum, $highestSum, $red);
			$links[] = MISC::aBrowse($colour, $size, $name, "index.php?action=listKeywordProcess" . 
			htmlentities("&id=" . $id)) . "&nbsp;[" . $this->sum[$id] . "]";
		}
		return join("&nbsp; ", $links);
	}
// Get keywordsfrom db
	function getKeywords()
	{
		list($condition, $bib) = $this->common->userBibCondition('WKX_resource_keyword');
		if($condition)
			$condition = " WHERE " . $condition;
		$recordset = $this->db->select(array('WKX_resource_keyword'), array('id', 'keywords'), $condition);
		while($row = $this->db->loopRecordSet($recordset))
			$this->collate($row);
		if($bib)
			$this->bib = $this->messages->text("user", "bibliography") . ": " . $bib;
		else if($this->session->getVar('setup_multiUser'))
			$this->bib = $this->messages->text("user", "bibliography") . ": " . 
				$this->messages->text("user", "masterBib");
	}
// Add keywords to array and sum totals
	function collate($row)
	{
		foreach(split(",", $row['keywords']) as $key => $value)
		{
			if($value)
				$keywords[] = "$value";
		}
		if(!isset($keywords))
			return FALSE;
		foreach($keywords as $keywordId)
		{
			if(!array_key_exists($keywordId, $this->sum))
				$this->sum[$keywordId] = 1;
			else
				++$this->sum[$keywordId];
			$keywordsCondition[] = "'$keywordId'";
		}
		if(!isset($keywordsCondition))
			return;
		$keywordsCondition = array_unique($keywordsCondition);
		$condition = $this->db->formatField('id') . "=" . join(" OR " .
			$this->db->formatField('id') . "=", $keywordsCondition);
		$recordset = $this->db->select(array('WKX_keyword'), array("id", "keyword"), 
			" WHERE " . $condition);
		while($row = $this->db->loopRecordSet($recordset))
			$this->keyword[$row['id']] = stripslashes($row['keyword']);
	}
}
?>

==> wikindx3_3_1.tar.gz: wikindx3/core/browse/BROWSEKEYWORD.php <==
<?php
/**********************************************************************************
WIKINDX: Bibliographic Management system.
Copyright (C)

This program is free software; you can redistribute it and/or modify it under the terms
of the GNU General Public License as published by the Free Software Foundation; either
version 2 of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License along with this program;
if not, write to the
Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA

The WIKINDX Team 2006
sirfragalot@users.sourceforge.net

**********************************************************************************/
/*****
* BROWSEKEYWORD class
*
* Browse keywords as a 'tag cloud'
*
* 
$Header: /cvsroot/wikindx/wikindx3/core/browse/BROWSEKEYWORD.php,v 1.7 2006/04/29 00:44:46 sirfragalot Exp $
*****/
class BROWSEKEYWORD
{
// Constructor
	function BROWSEKEYWORD($db, $vars)
	{
		$this->db = $db;
		$this->vars = $vars;
		include_once("core/html/MISC.php");
		include_once("core/html/HTML.php");
		$this->html = new HTML();
		include_once("core/messages/MESSAGES.php");
		$this->messages = new MESSAGES();
		include_once("core/template/TEMPLATE.php");
		$this->template = new TEMPLATE('content');
		include_once("core/browse/BROWSECOMMON.php");
		$this->common = new BROWSECOMMON($this->db);
		include_once("core/session/SESSION.php");
		$this->session = new SESSION();
	}
// display keywords
	function display()
	{
		$this->template->setVar('heading', $this->messages->text("heading", "browseKeyword"));
		$this->sum = $this->keyword = array();
		$this->getKeywords();
		if(empty($this->keyword))
		{
			$pString = MISC::p("&nbsp;") . $this->messages->text("misc", "noKeywords");
			$this->template->setVar('body', $pString);
			return $this->template->process();
		}
		natcasesort($this->sum);
		natcasesort($this->keyword);
		$this->keyword = $this->common->paging($this->vars, $this->keyword);
		$pString = MISC::p($this->bib, "hint") . $this->common->linksInfo() . 
			MISC::pBrowse($this->process(), "center");
		$this->template->setVar('body', $pString);
		$this->template->setVar('paging', $this->common->pagingLinks("action=browseKeyword"));
		return $this->template->process();
	}
// Process and display results
	function process()
	{
		$lowestSum = current($this->sum);
		$highestSum = end($this->sum);
		foreach($this->keyword as $id => $name)
		{
//			$name = str_replace(' ', "&nbsp;", $name);
			$name = $this->html->codeToHtml($name);
			list($red, $colour) = $this->common->colourText($lowestSum, $highestSum, $this->sum[$id]);
			$size = $this->common->sizeText($lowestSum, $highestSum, $red);
			$links[] = MISC::aBrowse($colour, $size, $name, "index.php?action=listKeywordProcess" . 
			htmlentities("&id=" . $id)) . "&nbsp;[" . $this->sum[$id] . "]";
		}
		return join("&nbsp; ", $links);
	}
// Get keywordsfrom db
	function getKeywords()
	{
		list($condition, $bib) = $this->common->userBibCondition('WKX_resource_keyword');
		if($condition)
			$condition = " WHERE " . $condition;
		$recordset = $this->db->select(array('WKX_resource_keyword'), array('id', 'keywords'), $condition);
		while($row = $this->db->loopRecordSet($recordset))
			$this->collate($row);
		if($bib)
			$this->bib = $this->messages->text("user", "bibliography") . ": " . $bib;
		else if($this->session->getVar('setup_multiUser'))
			$this->bib = $this->messages->text("user", "bibliography") . ": " . 
				$this->messages->text("user", "masterBib");
	}
// Add keywords to array and sum totals
	function collate($row)
	{
		foreach(split(",", $row['keywords']) as $key => $value)
		{
			if($value)
				$keywords[] = "$value";
		}
		if(!isset($keywords))
			return FALSE;
		foreach($keywords as $keywordId)
		{
			if(!array_key_exists($keywordId, $this->sum))
				$this->sum[$keywordId] = 1;
			else
				++$this->sum[$keywordId];
			$keywordsCondition[] = "'$keywordId'";
		}
		if(!isset($keywordsCondition))
			return;
		$keywordsCondition = array_unique($keywordsCondition);
		$condition = $this->db->formatField('id') . "=" . join(" OR " .
			$this->db->formatField('id') . "=", $keywordsCondition);
		$recordset = $this->db->select(array('WKX_keyword'), array("id", "keyword"), 
			" WHERE " . $condition);
		while($row = $this->db->loopRecordSet($recordset))
			$this->keyword[$row['id']] = preg_replace("/{(.*)}/U", "$1", stripslashes($row['keyword']));
	}
}
?>
